#include <qlineedit.h>
#include <qcombobox.h>
#include <qpixmap.h>
#include "createcategory.h"
#include "categories.h"
#include "pstore.h"

/* 
 *  Constructs a CreateCategory which is a child of 'parent', with the 
 *  name 'name' and widget flags set to 'f' 
 *
 *  The dialog will by default be modeless, unless you set 'modal' to
 *  TRUE to construct a modal dialog.
 */
CreateCategory::CreateCategory(PasswordStore *, QWidget* parent,  const char* name, WFlags fl )
    : CreateCategoryUI( parent, name,true, fl )
{	
	QPixmap *pixmap;
	int npix=numberOfCategoryPixmaps();
	for(int i=0;i<npix;i++){
	    pixmap=getCategoryPixmapByIndex(i);
		wIcon->insertItem(*pixmap);	
	}
		
	connect(wName,SIGNAL(returnPressed ()),this,SLOT(accept()));
}

/*  
 *  Destroys the object and frees any allocated resources
 */
CreateCategory::~CreateCategory()
{
    // no need to delete child widgets, Qt does it all for us
}

QString CreateCategory::pixmap(){
	return getCategoryPixmapName(wIcon->currentItem());	
}

QString CreateCategory::category(){
	return wName->text();
}

bool CreateCategory::EditCategory(QWidget *parent, PasswordStore *pstore, QString category){
	CreateCategory cc(pstore,parent);
	cc.setCaption(tr("Edit Category"));

	cc.lineEdit()->setText(category);
	
	QString pixmap = pstore->getCategoryPixmap(category);
	int cp = getCategoryPixmapIndex(pixmap);
	if(cp>=0){
		cc.comboBox()->setCurrentItem(cp);
	}

	if(QDialog::Accepted==cc.exec()){
		QString ncategory = cc.category();
		if(ncategory != category){
			printf("Renaming category\n");
			pstore->renameCategory(category,ncategory);

		}
		pstore->setCategoryPixmap(cc.category(),cc.pixmap());
		return true;
	}
	return false;
}
