#include <stdlib.h>
#include <time.h>
#include <qpe/config.h>

#include <qcheckbox.h>
#include <qspinbox.h>
#include <qlineedit.h>
#include "createpassword.h"

/* 
 *  Constructs a CreatePassword which is a child of 'parent', with the 
 *  name 'name' and widget flags set to 'f' 
 *
 *  The dialog will by default be modeless, unless you set 'modal' to
 *  TRUE to construct a modal dialog.
 */
CreatePassword::CreatePassword( QWidget* parent, Config *config)
    : CreatePasswordUI( parent,0, true), mConfig(config)
{
	srand(time(NULL));

	wSmallAlpha->setChecked(mConfig->readBoolEntry("createpassword.smallalpha",true));		
	wLargeAlpha->setChecked(mConfig->readBoolEntry("createpassword.largealpha",true));		
	wNumbers->setChecked(mConfig->readBoolEntry("createpassword.numbers",true));		
	wSpecial->setChecked(mConfig->readBoolEntry("createpassword.special",true));		

	wLength->setValue(mConfig->readNumEntry("createpassword.length",8));
}

void CreatePassword::accept(){
	mConfig->writeEntry("createpassword.smallalpha",wSmallAlpha->isChecked());
	mConfig->writeEntry("createpassword.largealpha",wLargeAlpha->isChecked());
	mConfig->writeEntry("createpassword.numbers",wNumbers->isChecked());
	mConfig->writeEntry("createpassword.special",wSpecial->isChecked());

	mConfig->writeEntry("createpassword.length",wLength->value());

	CreatePasswordUI::accept();
}

void CreatePassword::createPassword(){
	
	char *cSmallAlpha = "abcdefghijklmnopqrstwvxyz";
	char *cLargeAlpha = "ABCDEFGHIJKLMNOPQRSTWVXYZ";
	char *cNumbers = "0123456789";
 	char *cSpecial = "!#$%&*?=+";

	char *alphabets[4];
	int asize[4];
	memset(alphabets,0,sizeof(alphabets));
	
	int ptr=0;	
	
	if(wSmallAlpha->isChecked()){
		alphabets[ptr]=cSmallAlpha;
		asize[ptr] = strlen(cSmallAlpha);
		ptr++;
	}
	if(wLargeAlpha->isChecked()){
		alphabets[ptr]=cLargeAlpha;
		asize[ptr] = strlen(cLargeAlpha);
		ptr++;
	}
	if(wNumbers->isChecked()){
		alphabets[ptr]=cNumbers;
		asize[ptr] = strlen(cNumbers);
		ptr++;
	}
	if(wSpecial->isChecked()){
		alphabets[ptr]=cSpecial;
		asize[ptr] = strlen(cSpecial);
		ptr++;
	}

	if(ptr==0){
		return;	
	}
	
	
	int length = wLength->value();

	QString password;
	while(length>0){
			short ac = rand()%ptr;
			char c = alphabets[ac][rand()%asize[ac]];
			password.append(c);
			length--;
	}
	
	wPassword->setText(password);	
}

/*  
 *  Destroys the object and frees any allocated resources
 */
CreatePassword::~CreatePassword()
{
    // no need to delete child widgets, Qt does it all for us
}

