#ifndef PSTORE_H
#define PSTORE_H

#include <stdio.h>

#include <gdbm.h>

#include <qstring.h>
#include <qstringlist.h>

#include "blowfish.h"

#define RANDOM_DEV "/dev/urandom"
#define PWD_VFD_LEN 6*8

#define DB_VERSION 0.5

#include "error.h"


class PasswordData {
	public:
		PasswordData():mName(""),mUser(""),mPassword(""),mNote(""){};

		char *encode(unsigned int *len,float version);
		bool decode(char *d,unsigned int len,float version);
		
		QString mName;
		QString mUser;
		QString mPassword;
		QString mNote;
};

class PasswordStore {
	protected:	
		PasswordStore(QString name="Default");

		bool checkPassword();
	public:
		static PasswordStore *open(QString &file);
		static PasswordStore *create(QString &file,QString &password);

		~PasswordStore();
		
		bool setPassword(QString &password);

		bool unlock(QString password){ setPassword(password);  return checkPassword(); }
		void lock();

		QStringList categoryList();
		QString getCategory(QString acct);
		void setCategory(QString acct,QString category);
		void renameCategory(QString oldname,QString newname);
		
		QString getCategoryPixmap(QString cat);
		void setCategoryPixmap(QString cat,QString pix);

		
		void initPassword(QString &passwd);

		void deleteAccount(QString name);
		bool accountExists(QString name);

		bool changePassword(QString name,QString newpassword);

		bool convert(float newVersion);
		
        void close();
        
		QStringList entries();

		PasswordData *load(QString name);
		bool save(PasswordData *d);
	protected:
		unsigned int mFlags;
		float mDBVersion;
		QString mName;
		GDBM_FILE mDB;
		Blowfish mBlowfish;
};



#endif
